package org.example;

import javax.xml.stream.XMLStreamException;

import org.apache.cxf.binding.soap.SoapFault;
import org.apache.cxf.binding.soap.interceptor.Soap11FaultOutInterceptor;
import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.message.Message;
import org.apache.cxf.phase.AbstractPhaseInterceptor;
import org.apache.cxf.phase.Phase;
/**
 * This interceptor runs just before create the SoapFault. 
 * At this point you can change the exception used to create the SoapFault message
 * In this interceptor we are only change the exception when it is an instance of XMLStreamException  
 */
public class SoapFaultOutInterceptor extends AbstractPhaseInterceptor<Message> {
	
	public SoapFaultOutInterceptor() {
		super(Phase.PREPARE_SEND);
		this.getBefore().add(Soap11FaultOutInterceptor.class.getName());
		// If you are using SOAP version 1.2
		//this.getBefore().add(Soap12FaultOutInterceptor.class.getName());
	}
 
	@Override
	public void handleMessage(final Message message) {
  		 System.out.println("********** Start Custom SoapFaul Interceptor ***********");
		
  		 // Original SoapFault
	     final Fault f = (Fault) message.getContent(Exception.class);
	     
	     // Only Customize XMLStreamException
	     if (f.getCause() instanceof XMLStreamException) {
	     
	    	 System.out.println("Original SoapFault:");
	    	 System.out.println("\tClass: " + f.getCause().getClass());
	    	 System.out.println("\tFaultCode :" + f.getFaultCode());
	     	 System.out.println("\tCause :" + f.getCause().getMessage());
	     
	    	 final Throwable myCustomError = new Throwable("This is a custom error message !!!"); 
	    	 final SoapFault myCustomFault = new SoapFault("Custom Error", myCustomError, f.getFaultCode());
	    		 
	    	 message.setContent(Exception.class, myCustomFault);
	     }
	     System.out.println("********** End Custom SoapFault Interceptor ***********");
	}
}
